/***************************************************************************
	ROI
	Cost-effectiveness of Incentives
	
	ROI for the second year of treatment.
	Panel A - ROI with INFO in controls.
	Panel B - ROI with INFO out of controls.
	
	We use regression to generate counterfactual collection values in treatment circles and compare the
	increase in collections sum(observed y1 - counterfactual y0) against the amount spent in honorariums.
	
	Date: 11 July 2013
	Author: Kunal Mangal
	
***************************************************************************/
clear all
set more off

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

**********************************
** Costs
**********************************

// Main Treatment
use "Coded Data/Honorarium Payments/140226 FY2013Q4 Honorarium Payments with Tax Deductions", clear

drop if circle_id == .

collapse (sum) total_pay_adj (first) subtreatment, by(circle_id)

rename total_pay_adj totalpay

collapse (sum) totalpay
gen id = 1

tempfile payments_main
sa `payments_main'

use "Coded Data//Honorarium Payments/140226 FY2013Q4 Honorarium Payments with Tax Deductions", clear

drop if circle_id == .

collapse (sum) total_pay_adj (first) subtreatment, by(circle_id)

rename total_pay_adj totalpay
rename subtreatment treatment

collapse (sum) totalpay, by(treatment)
gen id = 1

tempfile payments_subs
sa `payments_subs'


*************************************************
** Additional Revenue
*************************************************

// Panel A - INFO in control, Panel B - INFO out of control

forval panel = 1/2 {

	// Calculate Revenue Increase - Main Treatment
	use "Coded Data/Phase III Analysis Data.dta", clear
	keep if fyear == 2013 & qtr == 4

	sort base_recov_tot_t

	gen _select_c_fixed = _select_c

	if `panel' == 1 reg ln_recov_tot_t _select_c base_ln_recov_tot_t stratdum_c* [aw = base_recov_tot_t]
	if `panel' == 2 reg ln_recov_tot_t _select_c INFO_sel base_ln_recov_tot_t stratdum_c* [aw = base_recov_tot_t]

	replace _select_c = 0

	predict y0
	replace y0 = exp(y0)

	replace _select_c = 1

	predict y1
	replace y1 = exp(y1)

	gen increase = y1 - y0

	replace _select_c = _select_c_fixed

	keep if _select_c_fixed == 1

	collapse (sum) increase
	gen id = 1
	
	merge 1:1 id using `payments_main'
	drop _merge
	drop id
	
	gen treatment = 0

	tempfile maintreat`panel'
	save `maintreat`panel''

	// Calculate Revenue Increase - Subtreatments
	use "Coded Data/Phase III Analysis Data.dta", clear
	keep if fyear == 2013 & qtr == 4

	sort base_recov_tot_t

	drop _select_c1 _select_c1all _select_c2 _select_c2all

	gen REV_sel_fixed = REV_sel
	gen REVPLS_sel_fixed = REVPLS_sel
	gen CFW_sel_fixed = CFW_sel

	if `panel' == 1 reg ln_recov_tot_t REV_sel REVPLS_sel CFW_sel base_ln_recov_tot_t stratdum_c* [aw = base_recov_tot_t]
	if `panel' == 2 reg ln_recov_tot_t REV_sel REVPLS_sel CFW_sel INFO_sel base_ln_recov_tot_t stratdum_c* [aw = base_recov_tot_t]

	replace REV_sel = 0
	replace REVPLS_sel = 0
	replace CFW_sel = 0

	predict y0
	replace y0 = exp(y0)

	replace REV_sel = REV_sel_fixed
	replace REVPLS_sel = REVPLS_sel_fixed
	replace CFW_sel = CFW_sel_fixed

	predict y1
	replace y1 = exp(y1)

	gen increase = y1 - y0

	keep if REV_sel_fixed == 1 | REVPLS_sel_fixed == 1 | CFW_sel_fixed == 1

	rename subtreatment treatment

	collapse (sum) increase, by(treatment)
	gen id = 1
	
	merge 1:1 id treatment using `payments_subs'
	drop _merge
	drop id
	
	tempfile subtreat`panel'
	save `subtreat`panel''

}

*** Panel A ****

use `maintreat1', clear
append using `subtreat1'

gen ROI = 100 * (increase / totalpay - 1)

order treatment increase totalpay ROI

format increase totalpay %12.0fc
format ROI %8.2f

label define treat 0 "Any treatment" 1 "Revenue" 2 "Revenue Plus" 3 "Flexible Bonus"
label values treatment treat

sort treat
list

estpost tabstat increase totalpay ROI, by(treatment) nototal
esttab using "${TABLE_OUTPUT}/tex/input/ROI_input.tex",  ///
	cells("increase(fmt(%12.0fc)) totalpay(fmt(%12.0fc)) ROI(fmt(%8.2f))")  style(tex) booktabs label compress ///
	noobs nonum nonote collabels("\specialcell{(1) \\ Additional Revenue}" "\specialcell{(2) \\ Cost of Incentives}" "\specialcell{(3) \\ ROI}") mlabels(none) ///
	substitute("\midrule" "\midrule \emph{Panel A: Information in controls} \\") ///
	nonotes fragment replace

	
*** Panel B ****

use `maintreat2', clear
append using `subtreat2'

gen ROI = 100 * (increase / totalpay - 1)

order treatment increase totalpay ROI

format increase totalpay %12.0fc
format ROI %8.2f

label define treat 0 "Any treatment" 1 "Revenue" 2 "Revenue Plus" 3 "Flexible Bonus"
label values treatment treat

sort treat
list

estpost tabstat increase totalpay ROI, by(treatment) nototal
esttab using "${TABLE_OUTPUT}/tex/input/ROI_input.tex",  ///
	cells("increase(fmt(%12.0fc)) totalpay(fmt(%12.0fc)) ROI(fmt(%8.2f))")  style(tex) booktabs label compress ///
	noobs nonum nonote collabels(none) mlabels(none) ///
	substitute("\midrule" "\midrule \emph{Panel B: Information out of controls} \\") ///
	fragment append


* WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file ROI

** WRITE TABLE NOTE
/*
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table estimates the economic return generated by the performance pay schemes."
file write tablenote " Additional Revenue due to Treatment is calculated with a reduced form regression of"
file write tablenote " log total revenue on log total baseline revenue, weighting observations by baseline revenue (in levels)."
file write tablenote " Panels A and B show how the calculation changes depending on whether the Information treatment is included in the controls (Panel A) or dummied out (Panel B)."
file write tablenote " For each treated observation, we generate a prediction of revenue collection under treatment and"
file write tablenote " a prediction of revenue collection in absence of treatment and subtract to calculate the additional"
file write tablenote " revenue due to treatment. The total additional revenue collection due to treatment is the sum of additional revenue collection across treated observations."
file write tablenote " Costs are the sum of incentive payments paid to circle staff under each scheme."
file write tablenote " The Return on Investment (ROI) is the percent increase in additional revenue above costs."

file close tablenote
*/

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
