/*******************************************************************************
WHO PAYS MORE - MAIN
Impacts on Tax Payments and Corruption, by Reassessed Status

Kunal Mangal
22 April 2014

SUMMARY: Main survey based regressions on property payments to tax department.
Panel A - Treatment
Panel B - Treatment * SEC9 with circle FE
Outcome vars: Tax payment, bribe payment, times tax inspector visited, perception of corruption.

** THIS VERSION INCLUDES A CONTROL FOR THE TAX REGRESSION IN THE RANDOM SAMPLE. **

*******************************************************************************/
version 12
clear all
set more off
set matsize 800

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************

use "Coded Data/survey_coded_data.dta", clear

label var _impl_c_xw "Treatment"
label var SEC9_impl_c_xw "Re-assessed * Treatment"
label var SEC9 "Re-assessed"

** REGRESSIONS *****************************************************************

// Objective Outcome
foreach yvar of varlist tax_last_payment {
			
	* Regress - Random Sample - Panel A
	eststo `yvar'_A : ///
	  ivreg `yvar' (_impl_c_xw =_select_c_xw) short_dummy phase2 stratdum_c* tax_last_payment_1011 ///
	    if SEC9 == 0, cluster(cluster_c)
	
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)'

	
	* Regress - Re-assessed - Panel B
	eststo `yvar'_B : ///
	  ivreg `yvar' (SEC9_impl_c_xw = SEC9_select_c_xw) SEC9 short_dummy ///
	    circlefe*, cluster(cluster_c)
		
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)'
	
	estadd local samp = "Full"
	
	* eststo `yvar' : combine_models2 `yvar'_A `yvar'_B, headings(A B)
}

// Subjective Outcomes
foreach yvar of varlist tax_payment_total tax_times_payment tax_corruption  {
			
	* Regress - Random Sample - Panel A
	eststo `yvar'_A : ///
	  ivreg `yvar' (_impl_c_xw =_select_c_xw) short_dummy stratdum_c* ///
	    if SEC9 == 0 & phase == 1, cluster(cluster_c)
		
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)'
	
	* Regress - Re-assessed - Panel B
	eststo `yvar'_B : ///
	  ivreg `yvar' (SEC9_impl_c_xw = SEC9_select_c_xw) SEC9 short_dummy ///
	    circlefe* if phase == 1, cluster(cluster_c)

	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)' 
	
	estadd local samp = "Phase 1"
			
	* eststo `yvar' : combine_models2 `yvar'_A `yvar'_B, headings(A B)
}


** TeX OUTPUT - RANDOM SAMPLE **************************************************

# delimit ;
esttab tax_last_payment_A tax_payment_total_A tax_times_payment_A 
  tax_corruption_A
	using "${TABLE_OUTPUT}/tex/input/who_pays_more_main_infocontrol_input.tex" , 
	keep(_impl_c_xw)
	
	b(%6.0g)
	se(%6.0g)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("\specialcell{Self-reported \\ Tax Payment}"
	  "\specialcell{Bribe Payment}"
	  "\specialcell{Frequency of \\ Bribe Payment}"
	  "\specialcell{Perception of \\ Corruption}") // Column headings

	refcat(
	  _impl_c_xw "\emph{Panel A: General Population Sample Only}", nolabel
	)
	stats(N ysumm,
	  labels("N" "Mean of control group")
	  fmt("%12.0f" "%12.3f")
	)
	//nonumbers // No column numbers
	label // Use Variable Labels	
	nonotes
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;
# delimit cr
	
** TeX OUTPUT - RE-ASSESSED PROPERTIES *****************************************
	
# delimit ;	
esttab tax_last_payment_B tax_payment_total_B tax_times_payment_B 
  tax_corruption_B
	using "${TABLE_OUTPUT}/tex/input/who_pays_more_main_infocontrol_input.tex" , 
	keep(SEC9_impl_c_xw SEC9)
	
	b(%6.0g)
	se(%6.0g)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	refcat(
		SEC9_impl_c_xw "\emph{Panel B: Re-assessed and General Population Sample}", nolabel
	)
	stats(N samp ysumm,
	  labels("N" "Sample" "Mean of control group in gen. pop. sample")
	  fmt("%12.0f" "a3" "%12.3f")
	)
	nomtitles // No model numbers	
	nonumbers // No column numbers
	label // Use Variable Labels
	nonotes
	booktabs // a nicer version of tables
	fragment
	append
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file who_pays_more_main_infocontrol

/*
** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "Property-level 2SLS regressions."
file write tablenote " Bribe Payment is the respondent's response to how much bribe they think others would pay for a similar property."
file write tablenote " Frequency of Bribe Payment and Perception of Corruption are graded on a 5 point rubric and scaled to the interval [0,1]."
file write tablenote " Panel A uses only properties from the random sample, while Panel B also pools re-assessed properties."
file write tablenote " The specifications in Panel A follow Equation 5.5 of the main text, with the exception of Column (1), which"
file write tablenote " controls for self-reported baseline (FY 2011) tax payment."
file write tablenote " Specifications in Panel B follow Equation 5.6 of the main text."
file write tablenote " For Columns (2-4), sample is restricted to Phase 1 circles."
file write tablenote " In both Panels A and B, specifications include a control for whether the response came from the short version of the survey,"
file write tablenote " and if the circle was sampled in Phase 2 (if applicable)."
file write tablenote " The Information treatment is included in the controls."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by robust partition,"
file write tablenote " the partition of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote
*/

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 

cap log close
