/*******************************************************************************
NON-REVENUE
Impacts on Non-Revenue Outcomes, Separating Information Treatment

Information Treatment OUT of controls

Wayne Aaron Sandholtz
24 January 2014

*******************************************************************************/
version 12
clear all
set more off

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************

***** YEAR 2 *****

use "Coded Data/survey_coded_data.dta", clear
keep if SEC9 == 0

label var _impl_c_xw "Any treatment"

label var REV_impl_xw "Revenue"
label var REVPLS_impl_xw "Revenue Plus"
label var CFW_impl_xw "Flexible Bonus"
label var INFO_impl_xw "Information"


// Phase 1 Only - Subjective Variables
foreach yvar of varlist tax_quality tax_satisfied {
		
	* Regress - Main Treatment - Part A
	eststo `yvar'_A : ///
	  ivreg `yvar' (_impl_c_xw INFO_impl_xw =_select_c_xw INFO_sel_xw) short_dummy stratdum_c*  if phase == 1, ///
	    cluster(cluster_c)

	
	* Regress - Subtreatments - Panel B
	eststo `yvar'_B : ///
	  ivreg `yvar' (REV_impl_xw REVPLS_impl_xw CFW_impl_xw INFO_impl_xw = ///
	    REV_sel_xw REVPLS_sel_xw CFW_sel_xw INFO_sel_xw) ///
		short_dummy stratdum_c* if phase == 1, cluster(cluster_c)
		  
	
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & INFO_sel_xw == 0
	estadd scalar ysumm	= `r(mean)'
	estadd local samp = "Phase 1"
	
	estadd joint REV_impl REVPLS_impl CFW_impl : `yvar'_B 
	estadd equivalence REV_impl REVPLS_impl CFW_impl: `yvar'_B
	estadd eqavg REV_impl REVPLS_impl CFW_impl, prefix(rvm_): `yvar'_B
	estadd eqavg CFW_impl REV_impl REVPLS_impl, prefix(ovs_): `yvar'_B
	
	eststo `yvar' : combine_models2 `yvar'_A `yvar'_B, headings(A B)
		
}

// Full Sample - Objective Variables
foreach yvar of varlist diff_pct_GARV diff_GARV {
		
	* Regress - Main Treatment - Part A
	eststo `yvar'_A : ///
	  ivreg `yvar' (_impl_c_xw INFO_impl_xw =_select_c_xw INFO_sel_xw) short_dummy phase2 stratdum_c*, ///
	    cluster(cluster_c)
	
	* Regress - Subtreatments - Panel B
	eststo `yvar'_B : ///
	  ivreg `yvar' (REV_impl_xw REVPLS_impl_xw CFW_impl_xw INFO_impl_xw = ///
	    REV_sel_xw REVPLS_sel_xw CFW_sel_xw INFO_sel_xw) ///
		short_dummy phase2 stratdum_c* `characteristics', cluster(cluster_c)
		  
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & INFO_sel_xw == 0
	estadd scalar ysumm	= `r(mean)'
	estadd local samp = "Full"
	
	estadd joint REV_impl REVPLS_impl CFW_impl : `yvar'_B 
	estadd equivalence REV_impl REVPLS_impl CFW_impl: `yvar'_B
	estadd eqavg REV_impl REVPLS_impl CFW_impl, prefix(rvm_): `yvar'_B
	estadd eqavg CFW_impl REV_impl REVPLS_impl, prefix(ovs_): `yvar'_B
	
	eststo `yvar' : combine_models2 `yvar'_A `yvar'_B, headings(A B)
		
}

** TeX OUTPUT ******************************************************************

# delimit ;
esttab tax_quality tax_satisfied diff_GARV diff_pct_GARV
	using "${TABLE_OUTPUT}/tex/input/nonrevenue_infoout_input.tex", 
	keep(_impl_c_xw REV_impl_xw REVPLS_impl_xw CFW_impl_xw INFO_impl_xw)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("Quality" "Satisfaction" "Inaccuracy" "Tax Gap") // Column headings
	
	eqlabels(
			//Embed latex code into the labels (emphasis)
			"\emph{Panel A: Main Treatment}"
			"\emph{Panel B: Subtreatments}"
			
			//prefix is added before every eqlabel, and suffix after every exlabel. 
			//Span forces column to span across rows, and @span is the width of the table
			// \addlinespace[1mm] adds extra space before table row. 
			prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
		)
		
	//nonumbers // No column numbers
	
	stats(N2 samp2 ysumm2 rvm_eqavg2 ovs_eqavg2 equivalence2 joint2,
		labels(
			"N"
			"Sample"
			"Mean of control group"
			"Rev. vs. Multitasking p."
			"Objective vs. Subjective p."
			"Equality of Schemes"
			"Joint significance"
		)	
		fmt(
			"%12.0f" "a3" "%12.3f" "%12.3f" "%12.3f" "%12.3f" "%12.3f"
		)
	)
	
	label // Use Variable Labels
	nonotes
	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file nonrevenue_infoout

** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table re-estimates Table 4 from the main text, separating the Information treatment from the control group. See Notes to Table 4 for additional information."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
cap log close
