*! Version 1 6feb2014 Wayne Aaron Sandholtz
/*
SUMMARY
	Hand texout the name of a .tex file (optionally preceded by its path
	relative to Stata's working directory), and texout will embed it in an 
	"\input{}" command inside a wrapper .tex file along with all the necessary
	commands to make it compile-ready (documentclass, usepackage, \begin{table},
	&c).
NB1:
	This program is designed to input .tex files like those produced by Stata's
	esttab command, which are written in the tabular environment by default.
NB2:
	Note that the input file need not actually exist in order for texout to run.
	It will write the wrapper .tex file which tells the LaTeX compiler where to
	look for the input file, but it's on you to make sure that file exists.
OPTIONS (NB3):
	INPUT -- whatever you put inside these parentheses is what will be inside
	  the "\input{}" command in this .tex file.  I almost made this a required
	  option, but decided not to in case people want to use this program to 
	  write .tex files which stand on their own and aren't wrappers for some 
	  other input file.  Still, I anticipate that in most cases you'll want to 
	  specify what goes inside "\input{}".  The default is "`filename'_input".
*/

********************************************************************************

cap pr drop texout
pr define texout, rclass
	version 12
	
	local cmdline `"`0'"'
	
	syntax anything [, INPUT(string)]

	local my = `"`1'"'

	if "`input'" != "" local isin input
	foreach x in my `isin'{
		** Parse the path
		tokenize `"``x''"', parse(/\)
		local tokenlen = 0
		local i = 1
		while `tokenlen' == 0{
			if "``i''" == "" local tokenlen = `i' - 1
			local ++i
		}
		
		** Put together the path
		local `x'dir
		forv i = 1/`= `tokenlen' - 1'{
			if "``i''" == "\" local `i' = "/"
			local `x'dir ``x'dir'``i''
		}

		** Isolate the part of the user input that is just the filename (no path)
		local `x'file = "``tokenlen''"
		
		** Take file extension off myfile if it's there
		gettoken `x'file ext : `x'file, parse(.)
	}
	
	** Recursion check.
	if `"`mydir'`myfile'"' == `"`inputdir'`inputfile'"'{
		di as error "Your output file and the specified input file are the same!"
		di as error "You can't write a tex file to wrap around itself!"
		exit
	}
	
	** Default input value
	if "`input'" != "" local inputfile `myfile'_input
	
	** Write the file **********************************************************
	# delimit ;
	cap file close x;
	file open x using "`mydir'`myfile'.tex" ///
	  , write replace;
	foreach thing in 
	`"\documentclass[preview, varwidth=\maxdimen, border=10pt]{standalone} 	"'
	`"\usepackage{amsmath}                                                  "'
	`"\usepackage{amsfonts}                                                 "'
	`"\usepackage{booktabs}                                                 "'
	`"\usepackage{titlesec}                                                 "'
	`"                                                                      "'
	`"% This is for word wrap in cells in tables.                           "'
	`"\newcommand{\specialcell}[2][c]{%                                     "'
	`"\begin{tabular}[#1]{@{}c@{}}#2\end{tabular}}                          "'
	`"                                                                      "'
	`"\titleformat{\section}                                                "'
	`"  {\normalfont\scshape}{\thesection}{1em}{}                           "'
	`"                                                                      "'
	`"\begin{document}                                                      "'
	`"\begin{table}[htp]                                                    "'
	`"\centering                                                            "'
	`"\scriptsize                                                           "'
	`"\input{"`inputdir'`inputfile'.tex"}                                  	"'
	`"\end{table}                                                           "'
	`"\end{document}                                                        "'{;
		file write x `"`thing'"' _n;
	};
	file close x;
	# delimit cr
	****************************************************************************
		
	** Return list
	return local cmdline `"`cmdline'"'
	return local myfile "`myfile'"
	return local mydir "`mydir'"
	return local inputfile "`inputfile'"
	return local inputdir "`inputdir'"
end
