/*******************************************************************************
UNENCRYPT AND COMPILE

Wayne Aaron Sandholtz
1 August 2013

Obeid Rehman
21 January 2014

Kunal
1 January 2015

SUMMARY: Get encrypted round 3 Survey data ready to be used in analysis.
		 140121 Update: Also adds Phase 2 survey data. Phase 2 data is in subfolder "Data 5,6,7"
OUTLINE:
	foreach section of the survey:
		1. Append together data from various rounds/phases
		2. Drop duplicates.
		3. Create a source dummy (long, short, logsheet, backmatch, sec9)
		4. Remove any identifiers
		5. Create a unique ID (circle_code cluster_id prop_no)
		6. Do any necessary cleaning.
		7. Name each variable according to the section it comes from.
		8. Save the compiled section.

*******************************************************************************/

version 12.0
clear all
set more off
* set mem 1000m
pause on

** SETUP AND MACROS ************************************************************

cap cd "${PAKTAX_ANALYSIS}"
global cryptdir "${PAKTAX_ANALYSIS}/Data/Raw Data/Survey Data/Round 3/"

** ERASE EXISITNG DATA, IF IT'S THERE ******************************************

foreach file in "Section 1" "Section 2" "Section 3" "Section 4" "Section 5" ///
	"Section 6" "Section 7" "Section 8" "Sec9_Log" "Sec9_Title" "Title" ///
	"Backmatch" "Log_Sec1" "Log_Sec2" "all_noid_data_sec9"{
	cap erase "Original Data/Survey Round 3/Compiled/`file'.dta"
	}

* Make directories if needed
cap mkdir "Data/Cleaned Data/Field Survey/"
cap mkdir "Data/Cleaned Data/Field Survey/Round 3/"
cap mkdir "Data/Cleaned Data/Field Survey/Round 3/Compiled"
cap mkdir "Data/Cleaned Data/Field Survey/Round 3/Compiled/Non-Section 9"
cap mkdir "Data/Cleaned Data/Field Survey/Round 3/Compiled/Section 9"
	
** PREP ***********************************************************************
*******************************************************************************
** VALUE LABELS
label define usage ///
	1 "Residential Self-Occupied" ///
	2 "Residential Rented" ///
	3 "Commercial Self-Occupied" ///
	4 "Commercial Rented" ///
	5 "Industrial Self-Occupied" ///
	6 "Industrial Rented" ///
	7 "Public Use exempted from tax (e.g. mosque)" ///
	8 "Office in residential area (i.e. does not have a shutter)" ///
	9 "Godown/workshop with tin shed" ///
	10 "Educational institution"
	
label define proptype ///
	1 "Residential" ///
	2 "Commercial" ///
	3 "Both Residential and Commercial" ///
	4 "Industrial" ///
	5 "Other (Specify)"

** SURVEY CIRCLE LIST
use "Data/Raw Data/Survey Data/130520 Circle Selection for Phase III Survey - All Circles.dta" ,clear
keep circle_id /*circle_name*/ svy_phase
sort circle_id
tempfile circlelist
sa `circlelist'

** COMPILE DATA ****************************************************************
********************************************************************************

** LOGSHEET 1 ******************************************************************
//Phase 1
u "${cryptdir}Data 1/Logsheet_BackMatching/Log_Sec1.dta", clear
append using "${cryptdir}Data 2/Logsheet_BackMatching/Log_Sec1.dta"
append using "${cryptdir}Data 3/Logsheet_BackMatching/Log_Sec1.dta"
gen phase=1

//Phase 2
append using "${cryptdir}Data 5/Logsheet_BackMatching/Log_Sec1.dta" 
append using "${cryptdir}Data 6/Logsheet_BackMatching/Log_Sec1.dta" 
append using "${cryptdir}Data 7/Logsheet_BackMatching/Log_Sec1.dta"
replace phase = 2 if phase!=1
duplicates drop

** SOURCE DUMMY
gen log_sec1 = 1

** REMOVE IDENTIFIERS
// none

** CREATE UNIQUE ID
// not at property level, it's circle level

** CLEAN AGAIN
ren circle_code circle_id
ds, has(type string)
local strings = "`r(varlist)'"
foreach var in `strings'{
	replace `var' = trim(`var')
	}
	
** SET-SPECIFIC VARIABLE NAMES
foreach var of varlist q*{
	rename `var' LS1_`var'
	}

** ALL CIRCLES PRESENT
preserve
	merge m:1 circle_id using `circlelist'
	assert _m==3
restore

saveold "Data/Cleaned Data/Field Survey/Round 3/Compiled/Log_Sec1.dta", replace
	
** LOGSHEET 2 ******************************************************************
// Renaming var name for Phase 2 data to match Phase 1
u "${cryptdir}Data 5/Logsheet_BackMatching/Log_Sec2.dta",clear
append using "${cryptdir}Data 6/Logsheet_BackMatching/Log_Sec2.dta"
append using "${cryptdir}Data 7/Logsheet_BackMatching/Log_Sec2.dta"

rename q11 q17 //
rename q4  q11 // Renaming order is important for these two
rename q5a q9a
rename q5b q9b
rename q5c q9c
rename q12 q18 //
rename q6  q12 // Renaming order is important for these two
rename q7  q13
rename q7_desc q13_desc
rename survey_id q14
rename q9  q15
rename q10 q16

gen phase = 2

tempfile phase2
sa `phase2'

//Phase 1
u "${cryptdir}Data 1/Logsheet_BackMatching/Log_Sec2.dta", clear
append using "${cryptdir}Data 2/Logsheet_BackMatching/Log_Sec2.dta"
append using "${cryptdir}Data 3/Logsheet_BackMatching/Log_Sec2.dta"
tostring q13_desc,replace
gen phase = 1

//Phase 2
append using `phase2'
duplicates drop circle_code cluster_id prop_no, force
	/* *WAS 131001: Obeid said there are 2411 duplicate entries in terms of
		these 3 identifying variables, and the reason they're not duplicates in
		terms of all other variables is because of leading spaces. */

** SOURCE DUMMY
gen log_sec2 = 1

** REMOVE IDENTIFIERS
drop q3 q11 q15-q18

** CREATE UNIQUE ID
foreach var in circle_code cluster_id prop_no{
	tostring `var', gen(`var'_str)
	gen len = length(`var'_str)
	qui sum len
	gen diff = `r(max)' - len
	qui sum diff
	assert `r(max)' <= 1 // this way we know we have to tack on at most one "0".
	
	replace `var'_str = "0" + `var'_str if diff == 1
	drop len diff
	}
gen prop_id = circle_code_str + cluster_id_str + prop_no_str
isid prop_id

** CLEAN AGAIN
ren circle_code circle_id
drop circle_code_str cluster_id_str prop_no_str
ds, has(type string)
local strings = "`r(varlist)'"
foreach var in `strings'{
	replace `var' = trim(`var')
	}
	
** VALUE LABELS
label copy status LS2_status
label values q13 LS2_status
label drop status

** MAKE VARIABLE NAMES SET-SPECIFIC
foreach var of varlist q*{
	rename `var' LS2_`var'
	}

** ALL CIRCLES PRESENT
preserve
	merge m:1 circle_id using `circlelist'
	assert _m==3
restore
	
saveold "Data/Cleaned Data/Field Survey/Round 3/Compiled/Log_Sec2.dta", replace

** BACKMATCH *******************************************************************
//Phase 1
u "${cryptdir}Data 1/Logsheet_BackMatching/Back_Matching.dta", clear
append using "${cryptdir}Data 2/Logsheet_BackMatching/Back_Matching.dta"
append using "${cryptdir}Data 3/Logsheet_BackMatching/Back_Matching.dta"
append using "${cryptdir}Data 4/Logsheet_BackMatching/Back_Matching.dta"    		// OR 131108
gen phase = 1

//Phase 2
append using "${cryptdir}Data 5/Logsheet_BackMatching/Back_Matching.dta"
drop if circle_code == 500101 //This data is wrong the correct data for this circle is in Data 6 below
append using "${cryptdir}Data 6/Logsheet_BackMatching/Back_Matching.dta"
append using "${cryptdir}Data 7/Logsheet_BackMatching/Back_Matching.dta"
replace phase = 2 if phase!=1

*CLEANING 
replace cluster_id=7 if cluster_id==3 & circle_code==500102
replace prop_no=7 if prop_no==8 & circle_code==500102 & cluster_id==7
replace prop_no=8 if prop_no==10 & circle_code==500102 & cluster_id==7
drop if circle_code==610000 & cluster_id==5 & prop_no==5
drop if circle_code==503300 & cluster_id==1 & prop_no==1
duplicates drop

** SOURCE DUMMY
gen back_matching = 1

** REMOVE IDENTIFIERS
drop q12 q16 /* Register number, Owner name, Comments */

** CREATE UNIQUE ID
foreach var in circle_code cluster_id prop_no{
	tostring `var', gen(`var'_str)
	gen len = length(`var'_str)
	qui sum len
	gen diff = `r(max)' - len
	qui sum diff
	assert `r(max)' <= 1 // this way we know we have to tack on at most one "0".
	replace `var'_str = "0" + `var'_str if diff == 1
	drop len diff
	}
gen prop_id = circle_code_str + cluster_id_str + prop_no_str
isid prop_id

** CLEAN AGAIN
ren circle_code circle_id
drop circle_code_str cluster_id_str prop_no_str
ds, has(type string)
local strings = "`r(varlist)'"
foreach var in `strings'{
	replace `var' = trim(`var')
	}
drop survey_id

** MAKE VARIABLE NAMES SET-SPECIFIC
foreach var of varlist q*{
	rename `var' BM_`var'
	}
	
** VALUE LABELS
label copy status BM_status
label values BM_q13 BM_status
label drop status

		local fixme2 ""
		foreach var of varlist _all{
			if inlist("`:val lab `var''","usage"){
				local fixme2 `fixme2' `var'
			}
		}
		cap label drop usage
		
		label define usage ///
			1 "Residential Self-Occupied" ///
			2 "Residential Rented" ///
			3 "Commercial Self-Occupied" ///
			4 "Commercial Rented" ///
			5 "Industrial Self-Occupied" ///
			6 "Industrial Rented" ///
			7 "Public Use exempted from tax (e.g. mosque)" ///
			8 "Office in residential area (i.e. does not have a shutter)" ///
			9 "Godown/workshop with tin shed" ///
			10 "Educational institution"
			
		foreach var in `fixme2'{
			label values `var' usage	
		}	

label values BM_q18c* usage

** ALL CIRCLES PRESENT
preserve
	merge m:1 circle_id using `circlelist'
	assert circle_id == 507300 if _merge==2     // 507300 Amin Park was not backmatched
restore

** SORT AND ORDER
order prop_id circle_id cluster_id cluster_cat prop_no
so prop_id

saveold "Data/Cleaned Data/Field Survey/Round 3/Compiled/Backmatch.dta", replace

** TITLE PAGE ******************************************************************
//Phase 1 Long
u "${cryptdir}Data 1/Long/TS_Long_Title.dta", clear
append using "${cryptdir}Data 2/Long/TS_Long_Title.dta"
append using "${cryptdir}Data 3/Long/TS_Long_Title.dta"
gen phase = 1

//Phase 2 Long
append using "${cryptdir}Data 5/Long/TS_Long_Title.dta"
append using "${cryptdir}Data 6/Long/TS_Long_Title.dta"
append using "${cryptdir}Data 7/Long/TS_Long_Title.dta"
replace phase = 2 if phase!=1
duplicates drop

** SOURCE DUMMY 
gen long_title = 1

//Phase 1 Short
append using "${cryptdir}Data 1/Short/TS_Short_Title.dta"
append using "${cryptdir}Data 2/Short/TS_Short_Title.dta"
append using "${cryptdir}Data 3/Short/TS_Short_Title.dta"
replace phase = 1 if phase==.

//Phase 2 Short
append using "${cryptdir}Data 5/Short/TS_Short_Title.dta"
append using "${cryptdir}Data 6/Short/TS_Short_Title.dta"
append using "${cryptdir}Data 7/Short/TS_Short_Title.dta"
replace phase = 2 if phase==.
duplicates drop

** MORE SOURCE DUMMIES 
gen short_title = 1 if long_title != 1


** CREATE UNIQUE ID
foreach var in circle_code cluster_id prop_no{
	tostring `var', gen(`var'_str)
	gen len = length(`var'_str)
	qui sum len
	gen diff = `r(max)' - len
	qui sum diff
	assert `r(max)' <= 1 // this way we know we have to tack on at most one "0".
	replace `var'_str = "0" + `var'_str if diff == 1
	drop len diff
	}
gen prop_id = circle_code_str + cluster_id_str + prop_no_str
isid prop_id

** CLEANING ENUM NAME/CODE BEFORE DROPPING ENUM NAME
destring enum_code, force replace
merge 1:1 prop_id using "${PAKTAX_ANALYSIS}/Data/Raw Data/Survey Data/enum_codes", update replace
drop if _merge == 2
drop _merge

** REMOVE IDENTIFIERS
drop enum_name survey_id q8* q9* q10* q11* q12* q13* //Drop identifiers


** CLEAN AGAIN
ren circle_code circle_id
drop circle_code_str cluster_id_str prop_no_str
ds, has(type string)
local strings = "`r(varlist)'"
foreach var in `strings'{
	replace `var' = trim(`var')
	}
	
** MAKE VARIABLE NAMES SET-SPECIFIC
foreach var of varlist q*{
	rename `var' T_`var'
	}

** ALL CIRCLES PRESENT
preserve
	merge m:1 circle_id using `circlelist'
	assert _m==3
restore
	
** SORT AND ORDER
order prop_id circle_id cluster_id cluster_cat prop_no
so prop_id

saveold "Data/Cleaned Data/Field Survey/Round 3/Compiled/Title.dta", replace


** NUMBERED SECTIONS ***********************************************************
/* *WAS: first just tostring every _desc_ variable to just let them append */
forv sec = 1/7{
	foreach batch in 1 2 3 5 6 7{
		foreach thing in Long Short{
			u "${cryptdir}Data `batch'/`thing'/TS_`thing'_Section`sec'", clear
			cap tostring *_desc*, replace
			cap tostring SEC6_q3, replace
			cap tostring SEC7_q7f, replace
			tempfile batch_`batch'_`thing'_sec`sec'
			sa `batch_`batch'_`thing'_sec`sec''
			}
		}
	}

	
forv x = 1/7 {			
	//Phase 1 Long
	u `batch_1_Long_sec`x'', clear
	di "trying 2 Long sec `x'"
	append using `batch_2_Long_sec`x''
	di "trying 3 Long sec `x'"
	append using `batch_3_Long_sec`x''
	gen phase = 1
	//Phase 2 Long
	di "trying 5 Long sec `x'"
	append using `batch_5_Long_sec`x''
	di "trying 6 Long sec `x'"
	append using `batch_6_Long_sec`x''
	di "trying 7 Long sec `x'"
	append using `batch_7_Long_sec`x''
	replace phase = 2 if phase!=1
	duplicates drop
** SOURCE DUMMY
	gen long_section`x' = 1
	
	//Phase 1 Short
	append using `batch_1_Short_sec`x''
	di "trying 2 Short sec `x'"
	append using `batch_2_Short_sec`x''
	di "trying 3 Short sec `x'"
	append using `batch_3_Short_sec`x''
	replace phase = 1 if phase==.
	//Phase 2 Short
	di "trying 5 Short sec `x'"
	append using `batch_5_Short_sec`x''
	di "trying 6 Short sec `x'"
	append using `batch_6_Short_sec`x''
	di "trying 7 Short sec `x'"
	append using `batch_7_Short_sec`x''
	replace phase = 2 if phase==.
	duplicates drop
** SOURCE DUMMY
	gen short_section`x' = 1 if long_section`x' != 1
	
** REMOVE IDENTIFIERS AND CLEAN						
	if `x' == 1{
		cap drop SEC1_q3
		cap drop SEC1_q7*
		cap drop SEC1_q8*
		cap drop SEC1_q9*
		cap drop SEC1_q10*
		cap drop SEC1_q11*
		cap drop SEC1_q15_desc
		}
		
	if `x' == 2 {          //Phase 2 New Variables adjustment
		foreach sub in c d{
			forval z = 1/3 {
				replace SEC2_q`z'`sub' = SEC2_q`z'`sub'_1 if phase==2
				drop SEC2_q`z'`sub'_1
			}
		}
	}	
		
	if `x' == 3{
		label copy purpose purpose_payment
		local fixme ""
		foreach var of varlist _all{
			if "`:val lab `var''" == "purpose"{
				local fixme `fixme' `var'
			}
		}
		foreach var in `fixme'{
			label values `var' purpose_payment	
		}
		label drop purpose

		label copy payment payment_sec3
		local fixme ""
		foreach var of varlist _all{
			if "`:val lab `var''" == "payment"{
				local fixme `fixme' `var'
			}
		}
		foreach var in `fixme'{
			label values `var' payment_sec3	
		}
		label drop payment

		}
	
	
	if `x' == 4 {
		
		forval z = 1/2 { //Phase 2 New Variables adjustment
			replace SEC4_q13_`z' = SEC4_q13c_`z' if phase==2
			drop SEC4_q13c_`z'
		}
		
		
	tostring *_desc*, replace
		cap drop SEC4_q14*
		cap drop SEC4_q15*
		cap drop SEC4_q22_desc*
		cap drop SEC4_q32
	
	local fixme ""
		foreach var of varlist _all{
			if inlist("`:val lab `var''","property","purpose","usage"){
				local fixme `fixme' `var'
			}
		}
		cap label drop property
		cap label drop purpose
		cap label drop usage
		
		label define usage ///
			1 "Residential Self-Occupied" ///
			2 "Residential Rented" ///
			3 "Commercial Self-Occupied" ///
			4 "Commercial Rented" ///
			5 "Industrial Self-Occupied" ///
			6 "Industrial Rented" ///
			7 "Public Use exempted from tax (e.g. mosque)" ///
			8 "Office in residential area (i.e. does not have a shutter)" ///
			9 "Godown/workshop with tin shed" ///
			10 "Educational institution"
			
		foreach var in `fixme'{
			label values `var' usage	
		}

		label copy payment payment_sec4
		local fixme ""
		foreach var of varlist _all{
			if "`:val lab `var''" == "payment"{
				local fixme `fixme' `var'
			}
		}
		foreach var in `fixme'{
			label values `var' payment_sec4
		}
		label drop payment		
	}
	
	if `x' == 5{
		label copy relation relation_sec5
		local fixme ""
		foreach var of varlist _all{
			if "`:val lab `var''" == "relation"{
				local fixme `fixme' `var'
			}
		}
		foreach var in `fixme'{
			label values `var' relation_sec5	
		}
		label drop relation	
	}
	
	if `x' == 6 {
		cap destring SEC6_q3, replace
		cap replace SEC6_q3 = . if SEC6_q3 == -99
	}
	if `x' == 7 {
		cap tostring *_desc, replace
		cap tostring SEC7_q7f, replace
		label copy property owned
		local fixme ""
		foreach var of varlist _all{
			if "`:val lab `var''" == "property"{
				local fixme `fixme' `var'
			}
		}
		foreach var in `fixme'{
			label values `var' owned	
		}
		label drop property
		
		label define usage ///
			1 "Residential Self-Occupied" ///
			2 "Residential Rented" ///
			3 "Commercial Self-Occupied" ///
			4 "Commercial Rented" ///
			5 "Industrial Self-Occupied" ///
			6 "Industrial Rented" ///
			7 "Public Use exempted from tax (e.g. mosque)" ///
			8 "Office in residential area (i.e. does not have a shutter)" ///
			9 "Godown/workshop with tin shed" ///
			10 "Educational institution"
			
		local fixme2 ""
		foreach var of varlist _all{
			if inlist("`:val lab `var''","propr","purpose"){
				local fixme2 `fixme2' `var'
			}
		}
		cap label drop purpose
		foreach var in `fixme2'{
			label values `var' usage	
		}	
	}
		
** CREATE UNIQUE ID
	foreach var in circle_code cluster_id prop_no{
		tostring `var', gen(`var'_str)
		gen len = length(`var'_str)
		qui sum len
		gen diff = `r(max)' - len
		qui sum diff
		assert `r(max)' <= 1 // this way we know we have to tack on at most one "0".
		replace `var'_str = "0" + `var'_str if diff == 1
		drop len diff
		}
	gen prop_id = circle_code_str + cluster_id_str + prop_no_str
	isid prop_id
	
** CLEAN AGAIN
	ren circle_code circle_id
	drop circle_code_str cluster_id_str prop_no_str
	ds, has(type string)
	local strings = "`r(varlist)'"
	foreach var in `strings'{
		replace `var' = trim(`var')
		}
		
** VARIABLE NAMES BY SECTION
	// these come with section-specific names 

** ALL CIRCLES PRESENT
	preserve
		merge m:1 circle_id using `circlelist'
		assert _m==3
	restore
	
** SORT AND ORDER
	order prop_id circle_id cluster_id cluster_cat prop_no
	so prop_id

	
	saveold "Data/Cleaned Data/Field Survey/Round 3/Compiled/Non-Section 9/Section `x'.dta", replace
}	

** SECTION 8 (has only Long, no Short) *****************************************
u "${cryptdir}Data 1/Long/TS_Long_Section8", clear
append using "${cryptdir}Data 2/Long/TS_Long_Section8"
append using "${cryptdir}Data 3/Long/TS_Long_Section8"
gen phase = 1 

// Phase 2
append using "${cryptdir}Data 5/Long/TS_Long_Section8"
append using "${cryptdir}Data 6/Long/TS_Long_Section8"
append using "${cryptdir}Data 7/Long/TS_Long_Section8"
replace phase=2 if phase!=1
duplicates drop


** SOURCE DUMMY
gen long_section8 = 1

** REMOVE IDENTIFIERS
	// none

** CREATE UNIQUE ID
foreach var in circle_code cluster_id prop_no{
	tostring `var', gen(`var'_str)
	gen len = length(`var'_str)
	qui sum len
	gen diff = `r(max)' - len
	qui sum diff
	assert `r(max)' <= 1 // this way we know we have to tack on at most one "0".
	replace `var'_str = "0" + `var'_str if diff == 1
	drop len diff
	}
gen prop_id = circle_code_str + cluster_id_str + prop_no_str
isid prop_id

** CLEAN AGAIN
ren circle_code circle_id
drop circle_code_str cluster_id_str prop_no_str
ds, has(type string)
local strings = "`r(varlist)'"
foreach var in `strings'{
	replace `var' = trim(`var')
	}
	
** VARIABLE NAMES BY SECTION
// these come with section-specific names

** VALUE LABELS
label copy area area_type
label values SEC8_q1 area_type
label drop area

** ALL CIRCLES PRESENT
preserve
	merge m:1 circle_id using `circlelist'
	assert _m==3
restore
	
** SORT AND ORDER
order prop_id circle_id cluster_id cluster_cat prop_no
so prop_id

saveold "Data/Cleaned Data/Field Survey/Round 3/Compiled/Non-Section 9/Section 8.dta", replace



** SECTION 9 DATA **************************************************************

** SEC9 LOGSHEET ***************************************************************
//Phase 1
u "${cryptdir}Data 2/SEC9/Section9.dta", clear
append using "${cryptdir}Data 3/SEC9/Section9.dta"
append using "${cryptdir}Data 4/SEC9/Section9.dta"
gen phase = 1

//Phase 2
append using "${cryptdir}Data 5/SEC9/Section9.dta"
append using "${cryptdir}Data 6/SEC9/Section9.dta"
append using "${cryptdir}Data 7/SEC9/Section9.dta"
replace phase=2 if phase!=1

** SOURCE DUMMY
gen SEC9 = 1
gen sec9_log = 1

** REMOVE IDENTIFIERS
drop q5_1
drop q5_2
drop q5_3

** CREATE UNIQUE ID
foreach var in circle_code cluster_id prop_no{
	tostring `var', gen(`var'_str)
	gen len = length(`var'_str)
	qui sum len
	gen diff = `r(max)' - len
	qui sum diff
	assert `r(max)' <= 4
	replace `var'_str = `var'_str if diff == 0
	replace `var'_str = "0" + `var'_str if diff == 1
	replace `var'_str = "00" + `var'_str if diff == 2
	replace `var'_str = "000" + `var'_str if diff == 3
	replace `var'_str = "0000" + `var'_str if diff == 4
	drop len diff
	}
gen prop_id = circle_code_str + cluster_id_str + prop_no_str
isid prop_id

** CLEAN AGAIN
drop circle_code_str cluster_id_str prop_no_str
ren circle_code circle_id
ds, has(type string)
local strings = "`r(varlist)'"
foreach var in `strings'{
	replace `var' = trim(`var')
	}
	
** VALUE LABELS
		local fixme2 ""
		foreach var of varlist _all{
			if inlist("`:val lab `var''","usage"){
				local fixme2 `fixme2' `var'
			}
		}
		cap label drop usage
		
		label define usage ///
			1 "Residential Self-Occupied" ///
			2 "Residential Rented" ///
			3 "Commercial Self-Occupied" ///
			4 "Commercial Rented" ///
			5 "Industrial Self-Occupied" ///
			6 "Industrial Rented" ///
			7 "Public Use exempted from tax (e.g. mosque)" ///
			8 "Office in residential area (i.e. does not have a shutter)" ///
			9 "Godown/workshop with tin shed" ///
			10 "Educational institution"
			
		foreach var in `fixme2'{
			label values `var' usage	
		}	
		
** SET-SPECIFIC VARIABLE NAMES
foreach var of varlist q*{
	rename `var' S9LOG_`var'
	}

** ALL CIRCLES PRESENT
preserve
	merge m:1 circle_id using `circlelist'
	assert `r(N)'==7
	assert  _m==2 if inlist(circle_id,200300,400400,402502,506901,507100,800521,902601) // 7 Circles with no Section 9 Data
restore


saveold "Data/Cleaned Data/Field Survey/Round 3/Compiled/Sec9_Log.dta", replace

** SEC9 CIRCLE TITLE ***********************************************************

// Fixing phase 2 variable names prior to appending
u "${cryptdir}Data 5/SEC9/Section9_Title.dta",clear
append using "${cryptdir}Data 6/SEC9/Section9_Title.dta"
append using "${cryptdir}Data 7/SEC9/Section9_Title.dta"
// Fix Me: Label are incorrect! need to fix them
foreach type in a b c{
	rename q5`type' q4`type'
	rename q6`type' q5`type'
	rename q7`type' q6`type'
	rename q8`type' q7`type'
}
tempfile data5section9_title
sa `data5section9_title'

//Phase 1
u "${cryptdir}Data 2/SEC9/Section9_Title.dta", clear
append using "${cryptdir}Data 3/SEC9/Section9_Title.dta"
append using "${cryptdir}Data 4/SEC9/Section9_Title.dta"     // OR 131108
gen phase = 1
duplicates drop

// Phase 2
append using `data5section9_title'
replace phase = 2 if phase != 1

** CLEANING LABELS
label variable q4a "January-June 31, 2013 : Number of new properties?"
label variable q4b "January-June 31, 2013 : Number of re-assessed properties?"
label variable q4c "January-June 31, 2013 : Total number of properties?"
label variable q9a "January-June 31, 2011 : Number of new properties?"
label variable q9b "January-June 31, 2011 : Number of re-assessed properties?"
label variable q9c "January-June 31, 2011 : Total number of properties?"
label variable q10a "July-Decemeber 31, 2010 : Number of new properties?"
label variable q10b "July-Decemeber 31, 2010 : Number of re-assessed properties?"
label variable q10c "July-Decemeber 31, 2010 : Total number of properties?"
label variable q11a "January-June 31, 2010 : Number of new properties?"
label variable q11b "January-June 31, 2010 : Number of re-assessed properties?"
label variable q11c "January-June 31, 2010 : Total number of properties?"
label variable q12a "July-Decemeber 31, 2009 : Number of new properties?"
label variable q12b "July-Decemeber 31, 2009 : Number of re-assessed properties?"
label variable q12c "July-Decemeber 31, 2009 : Total number of properties?"
order q4a q4b q4c,after(q4)



** SOURCE DUMYY
gen SEC9 = 1
gen sec9_title = 1

** NO IDENTIFIERS

** UNIQUE AT CIRCLE LEVEL, NOT PROPERTY

** CLEAN AGAIN
ren circle_code circle_id
ds, has(type string)
local strings = "`r(varlist)'"
foreach var in `strings'{
	replace `var' = trim(`var')
	}
		
** SET-SPECIFIC VARIABLE NAMES (and destring)
foreach var of varlist q*{
	destring `var', replace
	rename `var' S9TITLE_`var'
	}

** ALL CIRCLES PRESENT
preserve
	merge m:1 circle_id using `circlelist'
	assert `r(N)'==5
	assert  _m==2 if inlist(circle_id,400400,402502,506901,507100,800521) // 5 Circles with no Section 9 Data
restore

** CLEANING

saveold "Data/Cleaned Data/Field Survey/Round 3/Compiled/Sec9_Title_Count.dta", replace
	
** SEC9 SURVEY TITLE ***********************************************************
//Phase 1
u "${cryptdir}Data 2/SEC9/TS_SEC9_Title.dta", clear
append using "${cryptdir}Data 3/SEC9/TS_SEC9_Title.dta"
append using "${cryptdir}Data 4/SEC9/TS_SEC9_Title.dta"  // OR 131108
gen phase = 1

//Phase 2
append using "${cryptdir}Data 5/SEC9/TS_SEC9_Title.dta"
append using "${cryptdir}Data 6/SEC9/TS_SEC9_Title.dta"
append using "${cryptdir}Data 7/SEC9/TS_SEC9_Title.dta"
replace phase=2 if phase!=1

** SOURCE DUMMY
gen SEC9 = 1
gen sec9_ts_title = 1

** CREATE UNIQUE ID
foreach var in circle_code cluster_id prop_no{
	tostring `var', gen(`var'_str)
	gen len = length(`var'_str)
	qui sum len
	gen diff = `r(max)' - len
	qui sum diff
	* assert `r(max)' <= 1 // this way we know we have to tack on at most one "0".
	assert `r(max)' <= 3
	replace `var'_str = `var'_str if diff == 0
	replace `var'_str = "0" + `var'_str if diff == 1
	replace `var'_str = "00" + `var'_str if diff == 2
	replace `var'_str = "000" + `var'_str if diff == 3
	drop len diff
	}
gen prop_id = circle_code_str + cluster_id_str + prop_no_str
isid prop_id

** ENUM CODE CLEANING
destring enum_code, force replace
merge 1:1 prop_id using "${PAKTAX_ANALYSIS}/Data/Raw Data/Survey Data/enum_codes", update replace
drop if _merge == 2
drop _merge

** REMOVE IDENTIFIERS
drop enum_name survey_id q8* q9* q10* q11* q12* q13*

** CLEAN AGAIN
ren circle_code circle_id
drop circle_code_str cluster_id_str prop_no_str
destring enum_code,replace
ds, has(type string)
local strings = "`r(varlist)'"
foreach var in `strings'{
	replace `var' = trim(`var')
	}
				
** MAKE VARIABLE NAMES SET-SPECIFIC
foreach var of varlist q*{
	rename `var' T_`var'
}

preserve
	merge m:1 circle_id using `circlelist'
	*assert _m==3
	*Assert fails for 8 circles. 4 in phase 1 and 4 in phase 2
restore

** SORT AND ORDER
order prop_id circle_id cluster_id cluster_cat prop_no
so prop_id 

saveold "Data/Cleaned Data/Field Survey/Round 3/Compiled/Sec9_Title.dta", replace
	
** NUMBERED SECTIONS ***********************************************************
/* *WAS: first just tostring every _desc_ variable to just let them append */
forv sec = 1/8{
	foreach batch in 2 3 4 5 6 7{             // OR 131108
		u "${cryptdir}Data `batch'/SEC9/TS_SEC9_Section`sec'", clear
		cap tostring *_desc*, replace
		cap tostring SEC7_q7f, replace
		tempfile batch_`batch'_sec`sec'
		sa `batch_`batch'_sec`sec''
		}
	}
	
forv x = 1/8 {
	//Phase 1
	u `batch_2_sec`x'', clear
	append using `batch_3_sec`x''
	append using `batch_4_sec`x''   // OR 131108
	gen phase = 1
	
	//Phase 2
	append using `batch_5_sec`x''
	append using `batch_6_sec`x''
	append using `batch_7_sec`x''
	replace phase = 2 if phase ==.
	duplicates drop

** SOURCE DUMMIES
	gen sec9_section`x' = 1
	gen Long = 1
	gen SEC9 = 1

** REMOVE IDENTIFIERS AND CLEAN
	if `x' == 1{
		cap drop SEC1_q3
		cap drop SEC1_q7*
		cap drop SEC1_q8*
		cap drop SEC1_q9*
		cap drop SEC1_q10*
		cap drop SEC1_q11*
		cap drop SEC1_q15_desc
	}
	
	if `x' == 2 {          //New Variables adjustment
		foreach sub in c d {
			forval z = 1/3 {
				replace SEC2_q`z'`sub' = SEC2_q`z'`sub'_1 if phase==2
				drop SEC2_q`z'`sub'_1
			}
		}
	}	
	if `x' == 3{
		label copy purpose purpose_payment
		local fixme ""
		foreach var of varlist _all{
			if "`:val lab `var''" == "purpose"{
				local fixme `fixme' `var'
			}
		}
		foreach var in `fixme'{
			label values `var' purpose_payment	
		}
		label drop purpose
		
		label copy payment payment_sec3
		local fixme ""
		foreach var of varlist _all{
			if "`:val lab `var''" == "payment"{
				local fixme `fixme' `var'
			}
		}
		foreach var in `fixme'{
			label values `var' payment_sec3	
		}
		label drop payment
	}
	if `x' == 4 {
		cap drop SEC4_q14*
		cap drop SEC4_q15*
		cap drop SEC4_q22_desc*
		cap drop SEC4_q32
		
		forval z = 1/2 {
			replace SEC4_q13_`z' = SEC4_q13c_`z' if phase==2
			drop SEC4_q13c_`z'
		}
					
		local fixme ""
		foreach var of varlist _all {
			if inlist("`:val lab `var''","property","purpose","usage"){
				local fixme `fixme' `var'
			}
		}
		cap label drop property
		cap label drop purpose
		cap label drop usage
		
		label define usage ///
			1 "Residential Self-Occupied" ///
			2 "Residential Rented" ///
			3 "Commercial Self-Occupied" ///
			4 "Commercial Rented" ///
			5 "Industrial Self-Occupied" ///
			6 "Industrial Rented" ///
			7 "Public Use exempted from tax (e.g. mosque)" ///
			8 "Office in residential area (i.e. does not have a shutter)" ///
			9 "Godown/workshop with tin shed" ///
			10 "Educational institution"
			
		foreach var in `fixme'{
			label values `var' usage	
		}
		
		label copy payment payment_sec4
		local fixme ""
		foreach var of varlist _all{
			if "`:val lab `var''" == "payment"{
				local fixme `fixme' `var'
			}
		}
		foreach var in `fixme'{
			label values `var' payment_sec4
		}
		label drop payment
	}

	if `x' == 5{
		label copy relation relation_sec5
		local fixme ""
		foreach var of varlist _all{
			if "`:val lab `var''" == "relation"{
				local fixme `fixme' `var'
			}
		}
		foreach var in `fixme'{
			label values `var' relation_sec5	
		}
		label drop relation	
	}
	
	if `x' == 6 {
		cap destring SEC6_q3, replace
		cap replace SEC6_q3 = . if SEC6_q3 == -99
	}
	if `x' == 7 {
		label copy property owned
		local fixme ""
		foreach var of varlist _all{
			if "`:val lab `var''" == "property"{
				local fixme `fixme' `var'
			}
		}
		foreach var in `fixme'{
			label values `var' owned	
		}
		label drop property
				
		local fixme2 ""
		foreach var of varlist _all{
			if inlist("`:val lab `var''","propr","purpose","usage"){
				local fixme2 `fixme2' `var'
			}
		}
		cap label drop purpose
		cap label drop propr
		cap label drop usage
		
		label define usage ///
			1 "Residential Self-Occupied" ///
			2 "Residential Rented" ///
			3 "Commercial Self-Occupied" ///
			4 "Commercial Rented" ///
			5 "Industrial Self-Occupied" ///
			6 "Industrial Rented" ///
			7 "Public Use exempted from tax (e.g. mosque)" ///
			8 "Office in residential area (i.e. does not have a shutter)" ///
			9 "Godown/workshop with tin shed" ///
			10 "Educational institution"
			
		foreach var in `fixme2'{
			label values `var' usage	
		}	
	}
	
	if `x' == 8{
		label copy area area_type
		label values SEC8_q1 area_type
		label drop area
	}
** CREATE UNIQUE ID
	foreach var in circle_code cluster_id prop_no{
		tostring `var', gen(`var'_str)
		gen len = length(`var'_str)
		qui sum len
		gen diff = `r(max)' - len
		qui sum diff
		assert `r(max)' <= 3 // this way we know we have to tack on at most 2 "0".
		replace `var'_str = "0"  + `var'_str if diff == 1
		replace `var'_str = "00"  + `var'_str if diff == 2
		replace `var'_str = "000"  + `var'_str if diff == 3
		drop len diff
		}
	gen prop_id = circle_code_str + cluster_id_str + prop_no_str
	isid prop_id
	
** CLEAN AGAIN
	ren circle_code circle_id
	drop circle_code_str cluster_id_str prop_no_str
	ds, has(type string)
	local strings = "`r(varlist)'"
	foreach var in `strings'{
		replace `var' = trim(`var')
		}
	
** VARIABLES NAMES ARE FINE.
		
** SORT AND ORDER
	order prop_id circle_id cluster_id cluster_cat prop_no
	so prop_id 
	isid prop_id
	
	saveold "Data/Cleaned Data/Field Survey/Round 3/Compiled/Section 9/Section `x'.dta", replace
}

** APPEND NON-SECTION 9 WITH SECTION 9 *****************************************

** NUMBERED SECTIONS
forval x = 1/8{
	use "Data/Cleaned Data/Field Survey/Round 3/Compiled/Non-Section 9/Section `x'.dta", clear
	append using "Data/Cleaned Data/Field Survey/Round 3/Compiled/Section 9/Section `x'.dta"
	replace SEC9 = 0 if missing(SEC9)
	duplicates drop
	saveold "Data/Cleaned Data/Field Survey/Round 3/Compiled/Section `x'.dta", replace
	}
